from django.conf.urls import url, include


app_name='shops'

urlpatterns = [
    url(r'^payments/', include('aparnik.packages.shops.payments.urls', namespace='payments')),
    url(r'^orders/', include('aparnik.packages.shops.orders.urls', namespace='orders')),
    url(r'^zarinpals/', include('aparnik.packages.shops.zarinpals.urls', namespace='zarinpals')),
]



# -*- coding: utf-8 -*-

from django.shortcuts import render, get_object_or_404, redirect, reverse
from django.http.response import JsonResponse


def install(request):

    context = {
        'title': 'نصب'
    }
    template_name = 'aparnik/index.html'
    return render(request, template_name=template_name, context=context)